@@ -230,7 +230,7 @@ dump_buffer (phuff_entropy_ptr entropy)
  * between calls, so 24 bits are sufficient.
  */
 
-inline
+/* inline */
 LOCAL(void)
 emit_bits (phuff_entropy_ptr entropy, unsigned int code, int size)
 /* Emit some bits, unless we are in gather mode */
@@ -283,7 +283,7 @@ flush_bits (phuff_entropy_ptr entropy)
  * Emit (or just count) a Huffman symbol.
  */
 
-inline
+/* inline */
 LOCAL(void)
 emit_symbol (phuff_entropy_ptr entropy, int tbl_no, int symbol)
 {
