@@ -24,7 +24,7 @@
 
 /*
  * $Source: /home/kde/kdesupport/js/jsint.h,v $
- * $Id: jsint.h,v 1.2 1998/08/28 08:08:50 dfaure Exp $
+ * $Id: jsint.h,v 1.2.2.1 1999/07/15 15:04:37 porten Exp $
  */
 
 #ifndef JSINT_H
@@ -794,7 +794,7 @@ void js_vm_error (JSVirtualMachine *vm);
  * hash value should be re-mapped to the correct range, for example,
  * with the mod operand.
  */
-static inline unsigned int
+static unsigned int
 js_count_hash (const char *data, unsigned int data_len)
 {
   unsigned int val = 0, i;
@@ -876,7 +876,7 @@ int js_vm_is_marked_ptr (void *ptr);
 
 /* Function. */
 
-static inline JSFunction *
+static JSFunction *
 js_vm_make_function (JSVirtualMachine *vm, void *implementation)
 {
   JSFunction *f = js_vm_alloc (vm, sizeof (*vm));
@@ -899,7 +899,7 @@ void js_vm_builtin_create (JSVirtualMachine *vm, JSNode *result,
 
 /* Array. */
 
-static inline void
+static void
 js_vm_make_array (JSVirtualMachine *vm, JSNode *n, unsigned int length)
 {
   unsigned int i;
@@ -914,7 +914,7 @@ js_vm_make_array (JSVirtualMachine *vm, JSNode *n, unsigned int length)
     n->u.varray->data[i].type = JS_UNDEFINED;
 }
 
-static inline void
+static void
 js_vm_expand_array (JSVirtualMachine *vm, JSNode *n, unsigned int length)
 {
   if (n->u.varray->length < length)
@@ -1003,7 +1003,7 @@ void js_vm_stacktrace (JSVirtualMachine *vm, unsigned int num_frames);
 
 /* Strings. */
 
-static inline void
+static void
 js_vm_make_string (JSVirtualMachine *vm, JSNode *n, const char *data,
 		   unsigned int data_len)
 {
@@ -1019,7 +1019,7 @@ js_vm_make_string (JSVirtualMachine *vm, JSNode *n, const char *data,
 }
 
 
-static inline void
+static void
 js_vm_make_static_string (JSVirtualMachine *vm, JSNode *n, const char *data,
 			  unsigned int data_len)
 {
@@ -1032,7 +1032,7 @@ js_vm_make_static_string (JSVirtualMachine *vm, JSNode *n, const char *data,
 }
 
 
-static inline int
+static int
 js_compare_strings (JSNode *a, JSNode *b)
 {
   unsigned int i;
@@ -1053,7 +1053,7 @@ js_compare_strings (JSNode *a, JSNode *b)
 }
 
 
-static inline char *
+static char *
 js_string_to_c_string (JSVirtualMachine *vm, JSNode *a)
 {
   char *cp;
